#ifndef PROBE_H
#define PROBE_H

#include <stdint.h>  /* for int32_t */

typedef void *POMP_Handle_t;

/*
    POMP functions for initialization/etc.

    POMP_Init() is called by the runtime.
    POMP_Finalize() must be called manually (with atexit()).
    POMP_Get_handle() is called by the runtime.
*/

int32_t POMP_Init(void);
void POMP_Finalize(void);
int32_t POMP_Get_handle(POMP_Handle_t *handle, char ctc[]);

/*
    POMP_Parallel_*() callback functions
*/
int32_t POMP_Parallel_enter(
    POMP_Handle_t *handle,
    int32_t thread_id,
    int32_t num_threads,
    int32_t if_expr_result,
    char ctc[]);
int32_t POMP_Parallel_begin(POMP_Handle_t *handle, int32_t thread_id);
int32_t POMP_Parallel_end(POMP_Handle_t *handle, int32_t thread_id);
int32_t POMP_Parallel_exit(POMP_Handle_t *handle, int32_t thread_id);

/*
    POMP_Loop_*() callback functions
*/
int32_t POMP_Loop_enter(
    POMP_Handle_t *handle,
    int32_t thread_id,
    int64_t chunk_size,
    int64_t init_iter,
    int64_t final_iter,
    int64_t incr,
    char ctc[]);
int32_t POMP_Loop_chunk_begin(POMP_Handle_t *handle,
    int32_t thread_id,
    int64_t init_iter,
    int64_t final_iter);
int32_t POMP_Loop_chunk_end(POMP_Handle_t *handle, int32_t thread_id);
int32_t POMP_Loop_exit(POMP_Handle_t *handle, int32_t thread_id);

#endif
